@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: rpmopen.c,v 1.118 2007/04/14 17:21:50 hany Exp $
+ * $Id: rpmopen.c,v 1.119 2008/11/13 23:59:59 hany Exp $
  */
 
 #include <config.h>
@@ -256,6 +256,7 @@ rpmResolveGPGPSignature(const char *nameRpm, const char *sigtarget,
     FILE *file;
     int rsize = 128, crsize;
     unsigned char buf[8192];
+    char *temp;
 
     /* Now run GPG */
     outpipe[0] = outpipe[1] = 0;
@@ -294,6 +295,10 @@ rpmResolveGPGPSignature(const char *nameRpm, const char *sigtarget,
         strcat(rpm->extra->sigs[sign]->resolve, buf);
     }
     fclose(file);
+    
+    temp = xmlStrdup(protectEmail(rpm->extra->sigs[sign]->resolve));
+    xmlFree(rpm->extra->sigs[sign]->resolve);
+    rpm->extra->sigs[sign]->resolve = temp;
 
     (void) waitpid(pid, &status, 0);
 }
